@@ -19,6 +19,7 @@ import Data.ByteString as B
                elem, length, zip, head, filter, minimum, isInfixOf)
 import Data.Serialize as S (encode)
 
+
 runCompile :: String -> FullConfig-> ImperativeMonad ()
 runCompile dir cfg
   = do t <- liftIO $ Tools.readFile (dir </> "input")
@@ -56,14 +57,15 @@ compile theRunMode text templates tabs mytitle mylanguage formulas
                                         templates
                                         tabs
                                         formulas)
-           HTML No  -> return
-                        (run b mylanguage mytitle
-                         (printPrepareTree (parseit minparsers text))
-                         (printPrepareTree (parseit minparsers text))
-                         (hostname . fullUrl $ st)
-                         templates
-                         tabs
-                         formulas)
+           HTML No  -> do --liftIO (Tools.writeFile "/home/dirk/dhudhu" (show (printPrepareTree(parseit minparsers text))))
+                          return
+                           (run b mylanguage mytitle
+                            (printPrepareTree (parseit minparsers text))
+                            (printPrepareTree (parseit minparsers text))
+                            (hostname . fullUrl $ st)
+                             templates
+                             tabs
+                             formulas)
            ExpandedTemplates No -> do return
                                        (run b mylanguage mytitle (parseit parsers text)
                                         (parseit parsers text)
