@@ -22,11 +22,12 @@ import MagicStrings
 import SimpleContributors
 import WikiHelper
 import MediaWikiParseTree
-import MediaWikiParser
 import Network.URL
 import Control.Monad.Except
 import System.Process
 import Data.Serialize as S (decode)
+import HtmlParser (parseHtml)
+
 
 notendyet ::
           (String -> ImperativeMonad String) ->
@@ -141,7 +142,7 @@ qIncludeAction wurl text
 
 qBookIncludeAction :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
 qBookIncludeAction cfg wurl text 
-  = if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}")
+  = if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return ""
       else
          do pp <- (liftIO (print d)) >> myfun
             case pp of
@@ -281,7 +282,7 @@ makeContributors uu
                    _ -> makeUrl3 (lemma (fullUrl st)) (hostname (fullUrl st))
        yy <- liftIO $ geturl theUrl
        let lang
-             = case (deepGet2 "html" (parseit minparsers yy)) of
+             = case (deepGet2 "html" (parseHtml yy)) of
                    ((Environment Tag (TagAttr _ m) _) : []) -> Map.lookup "lang" m
                    _ -> Nothing
        return
@@ -420,6 +421,14 @@ loadHTML st
          x <- liftIO (geturl2 (exportURL (url fu)))
          return . C.decode . unpack $ x
 
+
+
+loadHTMLnoQuote :: ImperativeState -> ImperativeMonad String
+loadHTMLnoQuote st
+  = let fu = fullUrl st in
+      do x <- liftIO (geturl2 (exportURL (url fu)))
+         return . C.decode . unpack $ x
+
 loadBookHTML :: ImperativeState -> ImperativeMonad String
 loadBookHTML st
   = let fu = fullUrl st in
