@@ -315,7 +315,7 @@ formPage m s
                      infoBox "Create Your PDF" $
                        do mytext
                             "To compile MediaWiki pages via LaTeX to PDF choose any URL from "
-                          H.a H.! A.href "http://en.wikipedia.org/" $ "Wikibooks"
+                          H.a H.! A.href "http://en.wikipedia.org/" $ "Wikipedia"
                           mytext
                             " or any other website running MediaWiki. If you intent to compile a wikibook make sure you use the link to the printable version of the book."
                           H.br
@@ -326,7 +326,7 @@ formPage m s
                             H.div $
                               do H.table $
                                    do H.tr $
-                                        do H.td "URL to the Wiki to be converted"
+                                        do H.td "Full web URL of the book page"
                                            H.td $
                                              do H.input H.! A.style wwidth H.! A.type_ "text" H.!
                                                   A.id "msg"
@@ -336,29 +336,29 @@ formPage m s
                                         do H.td "Output Format"
                                            H.td $
                                              do H.select H.! A.style wwidth H.! A.name "output" $
-                                                  do H.option H.! A.value "pdf" $ "Compiled PDF"
-                                                     H.option H.! A.value "zip" $ "Source ZIP"
-                                                     H.option H.! A.value "epub" $ "EPUB File"
+                                                  do H.option H.! A.value "pdf" $ "PDF"
+                                                     H.option H.! A.value "zip" $ "LaTeX zip"
+                                                     H.option H.! A.value "epub" $ "EPUB"
                                                      H.option H.! A.value "odt" $
-                                                       "ODT File (Word Processor)"
+                                                       "ODT (Word Processor)"
                                       H.tr $
                                         do H.td "Template expansion"
                                            H.td $
                                              do H.select H.! A.style wwidth H.! A.name "expansion" $
-                                                  do H.option H.! A.value "Print" $ "Print"
-                                                     H.option H.! A.value "BookMode" $ "BookMode"
-                                                     H.option H.! A.value "MediaWiki" $ "Mediawiki"
-                                                     H.option H.! A.value "Normal" $ "Normal"
+                                                  do H.option H.! A.value "Print" $ "Standard"
+                                                     H.option H.! A.value "BookMode" $ "Book / Collection"
+                                                     H.option H.! A.value "MediaWiki" $ "Expand Templates by MediaWiki"
+                                                     H.option H.! A.value "Normal" $ "Expand Templates Internally"
                                       H.tr $
-                                        do H.td "Paper"
+                                        do H.td "Page size"
                                            H.td $
                                              do H.select H.! A.style wwidth H.! A.name "paper" $
                                                   do H.option H.! A.value "A4" $ "A4"
                                                      H.option H.! A.value "A5" $ "A5"
                                                      H.option H.! A.value "B5" $ "B5"
-                                                     H.option H.! A.value "letter" $ "letter"
-                                                     H.option H.! A.value "legal" $ "legal"
-                                                     H.option H.! A.value "executive" $ "executive"
+                                                     H.option H.! A.value "letter" $ "Letter"
+                                                     H.option H.! A.value "legal" $ "Legal"
+                                                     H.option H.! A.value "executive" $ "Executive"
                                       H.tr $
                                         do H.td "Vector graphics"
                                            H.td $
@@ -381,12 +381,12 @@ formPage m s
                              H.br
                              H.div H.! A.style "font-size:large" $ H.b "There is a time limit of one hour (≈ 200 pages in PDF) on this server!"
                              H.br
-                             mytext "Requests taking longer will be terminated and a \"Conversion Failed due to timeout or non zero exit code\" message will be displayed. There is no limit in the downloadable versions shown on the right." 
+                             mytext "Requests taking longer will be terminated and a \"Conversion Failed due to timeout or non zero exit code\" message will be displayed. There is no limit in the downloadable version of the software, see link on right." 
 
         getRunmode "Print" = ImperativeState.HTML ImperativeState.No
         getRunmode "MediaWiki" = ImperativeState.ExpandedTemplates ImperativeState.No
         getRunmode "Normal" = ImperativeState.StandardTemplates ImperativeState.No
-        getRunmode "BookMode" = ImperativeState.HTML ImperativeState.No 
+        getRunmode "BookMode" = ImperativeState.HTML ImperativeState.Yes 
         getRunmode _ = ImperativeState.HTML ImperativeState.No
         
         processForm :: ServerPart Response
