@@ -18,6 +18,7 @@ import Control.Monad
 import Licenses
 import Tools
 import ImperativeState
+import HtmlParser (parseHtml)
 
 makeUrl2 :: String -> String -> [Char]
 makeUrl2 theLemma theHost
@@ -90,7 +91,7 @@ simpleContributors theLemma theHost uu st
                    Just u -> exportURL u
                    _ -> makeUrl3 theLemma theHost
        yy <- geturl theUrl3
-       let gg = (deepGet "li" "id" "ca-history" (parseit minparsers yy))
+       let gg = (deepGet "li" "id" "ca-history" (parseHtml yy))
        let theUrl
              = makeUrl4
                  (case gg of
@@ -117,13 +118,13 @@ simpleContributors theLemma theHost uu st
        let y = decodeString yy
        let x = decodeString xx
        let dd
-             = ((deepGet "a" "class" "new mw-userlink" (parseit minparsers x))
-                  ++ (deepGet "a" "class" "mw-userlink" (parseit minparsers x)))
+             = ((deepGet "a" "class" "new mw-userlink" (parseHtml x))
+                  ++ (deepGet "a" "class" "mw-userlink" (parseHtml x)))
                  :: [Anything Char]
        let ll = (filter pre (map go dd))
        let n = (nub ll) :: [(String, String)]
        let out = map go2 (zip (map (count ll) n) n)
-       let ht = (parseit htmlminparsers y)
+       let ht = (parseHtml y)
        case (getAuthor ht) of
            Just zz -> return
                         [(fst
